#
##  1、什么是MuskTest

MuskTest是一个无需写代码，就可以完成接口自动化测试的轻量级框架，只需要通过json或yaml文件编写非常简洁的用例数据，即可完成接口自动化测试，并生成自动化测试报告。旨在帮助更多不会写代码的小伙伴掌握接口自动化测试的能力。框架使用起来非常简单，易上手，只需要几个小时就能掌握！


- ##### 开发者：码思客—木森
- ##### 微信:musen9111

- ##### 大家在使用过程中发现bug,以及使用过程中有什么问题，可以联系我
## 2、安装MuskTest

apin是基于python3.6开发的，安装前请确认你的python版本>3.6

- **安装命令**

    `
    pip install MuskTest
    `
    
## 3、使用文档：https://musktest.readthedocs.io/zh_CN/latest/